Keyboard shortcuts

Press or to navigate between chapters

Press S or / to search in the book

Press ? to show this help

Press Esc to hide this help

Android drawable profile

Purpose

The profile is designed to import vector images resources as an android drawable XML vector resources. Light/dark options (night) are supported.

Default loading process

The asset import process consists of the following stages:

  1. Fetch Figma remote: REST API reference
  2. Locate the node ID by the specified name
  3. Request SVG export from Figma using the node ID: REST API reference
    • Includes dark theme variants when configured (night)
  4. Download SVG assets
  5. Simplify SVG assets and transform them to Android drawable XML vector resources
  6. Organize outputs in standard Android resource structure:
    • drawable/
    • drawable-night/

Complete Configuration in .figtree.toml

[profiles.android-drawable]
# ID from the [remotes] section.
# Uses the default remote if unspecified, but can reference any configured remote
remote = "some_remote_id"
# Root Android resources directory
# (parent of drawable-* folders)
android_res_dir = "src/main/res"
# Dark theme configuration
# Naming pattern for dark theme variants
# {base} is replaced with base asset name
# Leave unspecified to disable dark theme support
night = "{base} / Dark"